@@ -1,7 +1,11 @@
-package Search::Elasticsearch::Client::5_0::Direct::Snapshot;
-$Search::Elasticsearch::Client::5_0::Direct::Snapshot::VERSION = '5.00';
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
+package Search::Elasticsearch::Client::7_0::Direct::Snapshot;
+$Search::Elasticsearch::Client::7_0::Direct::Snapshot::VERSION = '7.711';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::7_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('snapshot');
 
@@ -13,11 +17,11 @@ __PACKAGE__->_install_api('snapshot');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Snapshot - A client for managing snapshot/restore
+Search::Elasticsearch::Client::7_0::Direct::Snapshot - A client for managing snapshot/restore
 
 =head1 VERSION
 
-version 5.00
+version 7.711
 
 =head1 DESCRIPTION
 
@@ -39,6 +43,8 @@ It does L<Search::Elasticsearch::Role::Client::Direct>.
 Create a repository for backups.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<verify>
@@ -55,6 +61,8 @@ for more information.
 Retrieve existing repositories.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -70,6 +78,8 @@ for more information.
 Verify existing repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -85,6 +95,8 @@ for more information.
 Delete repositories by name.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -104,6 +116,8 @@ Create a snapshot of the whole cluster or individual indices in the named
 repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<wait_for_completion>
 
@@ -117,8 +131,11 @@ Query string parameters:
 Retrieve snapshots in the named repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<ignore_unavailable>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<verbose>
 
 See the L<"snapshot/restore docs"|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-snapshot.html>
 for more information.
@@ -133,6 +150,8 @@ for more information.
 Delete snapshot in the named repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>
 
 See the L<"snapshot/restore docs"|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-snapshot.html>
@@ -150,6 +169,8 @@ for more information.
 Restore a named snapshot.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<wait_for_completion>
 
@@ -166,6 +187,8 @@ for more information.
 Returns status information about the specified snapshots.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>
 
@@ -174,11 +197,11 @@ for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2021 by Elasticsearch BV.
 
 This is free software, licensed under:
 
